exceptiontools.ContainmentError
===============================

.. abjad-lineage:: abjad.tools.exceptiontools.ContainmentError.ContainmentError

.. autoclass:: abjad.tools.exceptiontools.ContainmentError.ContainmentError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.ContainmentError.ContainmentError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ContainmentError.ContainmentError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ContainmentError.ContainmentError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ContainmentError.ContainmentError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ContainmentError.ContainmentError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ContainmentError.ContainmentError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ContainmentError.ContainmentError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ContainmentError.ContainmentError.__unicode__
   :noindex:
